@@ -3,7 +3,7 @@ BEGIN {
   $Eval::Closure::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Eval::Closure::VERSION = '0.10';
+  $Eval::Closure::VERSION = '0.11';
 }
 use strict;
 use warnings;
@@ -24,6 +24,9 @@ use constant HAS_LEXICAL_SUBS => $] >= 5.018;
 sub eval_closure {
     my (%args) = @_;
 
+    # default to copying environment
+    $args{alias} = 0 if !exists $args{alias};
+
     $args{source} = _canonicalize_source($args{source});
     _validate_env($args{environment} ||= {});
 
@@ -31,7 +34,7 @@ sub eval_closure {
                   . $args{source}
         if defined $args{description} && !($^P & 0x10);
 
-    my ($code, $e) = _clean_eval_closure(@args{qw(source environment)});
+    my ($code, $e) = _clean_eval_closure(@args{qw(source environment alias)});
 
     if (!$code) {
         if ($args{terse_error}) {
@@ -100,15 +103,15 @@ sub _line_directive {
 }
 
 sub _clean_eval_closure {
-    my ($source, $captures) = @_;
+    my ($source, $captures, $alias) = @_;
 
     my @capture_keys = sort keys %$captures;
 
     if ($ENV{EVAL_CLOSURE_PRINT_SOURCE}) {
-        _dump_source(_make_compiler_source($source, @capture_keys));
+        _dump_source(_make_compiler_source($source, $alias, @capture_keys));
     }
 
-    my ($compiler, $e) = _make_compiler($source, @capture_keys);
+    my ($compiler, $e) = _make_compiler($source, $alias, @capture_keys);
     my $code;
     if (defined $compiler) {
         $code = $compiler->(@$captures{@capture_keys});
@@ -120,6 +123,12 @@ sub _clean_eval_closure {
         undef $code;
     }
 
+    if ($alias) {
+        require Devel::LexAlias;
+        Devel::LexAlias::lexalias($code, $_, $captures->{$_})
+            for grep !/^\&/, keys %$captures;
+    }
+
     return ($code, $e);
 }
 
@@ -140,20 +149,20 @@ sub _clean_eval {
 $Eval::Closure::SANDBOX_ID = 0;
 
 sub _make_compiler_source {
-    my ($source, @capture_keys) = @_;
+    my ($source, $alias, @capture_keys) = @_;
     $Eval::Closure::SANDBOX_ID++;
     my $i = 0;
     return join "\n", (
         "package Eval::Closure::Sandbox_$Eval::Closure::SANDBOX_ID;",
         'sub {',
-            (map { _make_lexical_assignment($_, $i++) } @capture_keys),
+            (map { _make_lexical_assignment($_, $i++, $alias) } @capture_keys),
             $source,
         '}',
     );
 }
 
 sub _make_lexical_assignment {
-    my ($key, $index) = @_;
+    my ($key, $index, $alias) = @_;
     my $sigil = substr($key, 0, 1);
     my $name = substr($key, 1);
     if (HAS_LEXICAL_SUBS && $sigil eq '&') {
@@ -163,6 +172,9 @@ sub _make_lexical_assignment {
              . 'my ' . $tmpname . ' = $_[' . $index . ']; '
              . 'my sub ' . $name . ' { goto ' . $tmpname . ' }';
     }
+    if ($alias) {
+        return 'my ' . $key . ';';
+    }
     else {
         return 'my ' . $key . ' = ' . $sigil . '{$_[' . $index . ']};';
     }
@@ -199,7 +211,7 @@ Eval::Closure - safely and cleanly create closures via string eval
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -263,6 +275,15 @@ sigil of C<&>. This will create a lexical sub in the evaluated code (see
 L<feature/The 'lexical_subs' feature>). Using a C<&> sigil on perl versions
 before lexical subs were available will throw an error.
 
+=item alias
+
+If set to true, the coderef returned closes over the variables referenced in
+the environment hashref. (This feature requires L<Devel::LexAlias>.) If set to
+false, the coderef closes over a I<< shallow copy >> of the variables.
+
+If this argument is omitted, Eval::Closure will currently assume false, but
+this assumption may change in a future version.
+
 =item description
 
 This lets you provide a bit more information in backtraces. Normally, when a
@@ -290,7 +311,8 @@ behavior so you get only the compilation error that Perl actually reported.
 
 No known bugs.
 
-Please report any bugs to GitHub Issues at L<https://github.com/doy/eval-closure/issues>.
+Please report any bugs to GitHub Issues at
+L<https://github.com/doy/eval-closure/issues>.
 
 =head1 SEE ALSO
 
